==> haskell-tz-0.1.3.6-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-I4yTfuKSr1rI6EDrcaDeFR
key:                  tz-0.1.3.6-I4yTfuKSr1rI6EDrcaDeFR
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  0dba88b6304daf26ac3f3a78ab30f5b2
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Internal.CoerceTH Data.Time.Zones.Read
    Data.Time.Zones.TH Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-I4yTfuKSr1rI6EDrcaDeFR
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW
    deepseq-1.4.5.0 template-haskell-2.17.0.0 time-1.9.3
    tzdata-0.2.20221011.0-yAHGVklIQ2DNv56jH8o5H
    vector-0.13.0.0-80dNWv5W93FGfZf7Ao5mAf

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tz-0.1.3.6-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-21EjspDd2I1Bgwl1eqQtw4
key:                  tz-0.1.3.6-21EjspDd2I1Bgwl1eqQtw4
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  f04411ab23d24321e9a9882b95ae08e1
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Internal.CoerceTH Data.Time.Zones.Read
    Data.Time.Zones.TH Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-21EjspDd2I1Bgwl1eqQtw4
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW
    deepseq-1.4.5.0 template-haskell-2.17.0.0 time-1.9.3
    tzdata-0.2.20221129.0-GpI4QYOIHjQ8uQ3SXyjq1M
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
